"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_ts_1 = require("@essential-projects/errors_ts");
class ExternalTaskApiInternalAccessor {
    constructor(externalApiService) {
        this._externalApiService = undefined;
        this._externalApiService = externalApiService;
    }
    async fetchAndLockExternalTasks(identity, workerId, topicName, maxTasks, longPollingTimeout, lockDuration) {
        this._ensureIsAuthorized(identity);
        return this
            ._externalApiService
            .fetchAndLockExternalTasks(identity, workerId, topicName, maxTasks, longPollingTimeout, lockDuration);
    }
    async extendLock(identity, workerId, externalTaskId, additionalDuration) {
        this._ensureIsAuthorized(identity);
        return this._externalApiService.extendLock(identity, workerId, externalTaskId, additionalDuration);
    }
    async handleBpmnError(identity, workerId, externalTaskId, errorCode) {
        this._ensureIsAuthorized(identity);
        return this._externalApiService.handleBpmnError(identity, workerId, externalTaskId, errorCode);
    }
    async handleServiceError(identity, workerId, externalTaskId, errorMessage, errorDetails) {
        this._ensureIsAuthorized(identity);
        return this._externalApiService.handleServiceError(identity, workerId, externalTaskId, errorMessage, errorDetails);
    }
    async finishExternalTask(identity, workerId, externalTaskId, payload) {
        this._ensureIsAuthorized(identity);
        return this._externalApiService.finishExternalTask(identity, workerId, externalTaskId, payload);
    }
    _ensureIsAuthorized(identity) {
        const authTokenNotProvided = !identity || typeof identity.token !== 'string';
        if (authTokenNotProvided) {
            throw new errors_ts_1.UnauthorizedError('No auth token provided!');
        }
    }
}
exports.ExternalTaskApiInternalAccessor = ExternalTaskApiInternalAccessor;

//# sourceMappingURL=internal_accessor.js.map
